using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using Utils.DataBase;
using PhoenixDLL.Class;
using Utils.Log;
using PhoenixDLL.Class.Managers;
using PhoenixDLL.GUI.Managers;

namespace PhoenixPrescription.GUI
{
    /// <summary>
    /// History of the patients which did not come to meetings
    /// </summary>
    public partial class fr_HistoriqueNonCameMeeting : Form
    {
        #region Constructor
        /// <summary>
        /// Constructor
        /// </summary>
        public fr_HistoriqueNonCameMeeting()
        {
            InitializeComponent();
        }
        #endregion

        #region Events
        /// <summary>
        /// The frame is loading
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Event_FrameLoad(object sender, EventArgs e)
        {
            try
            {
                OleDbSql SqlManager = new OleDbSql(Options.Instance.Path);
                string SqlQuery = "SELECT p.Nom, p.Prenom, p.DateNaissance, r.Debut, r.id_rdv,"
                + " FORMAT(r.Fin, \"hh:nn\")as Fin, p.Honoraire"
                + " FROM Patient p, RendezVous r WHERE r.id_Patient = p.id_Patient"
                + " AND r.came_to_rdv = true AND r.a_paye = false;";
                DataSet ds = new DataSet();
                int res = SqlManager.ExecuteSql(SqlQuery, ref ds);
                if (res < 1)
                {
                    MessageBox.Show("Il n'y a aucun rendez-vous non pay!", "Information", MessageBoxButtons.OK, MessageBoxIcon.Information);
                    this.Close();
                }

                #region DataGridView displaying
                dgv_NonMeetings.DataSource = ds.Tables[0];
                dgv_NonMeetings.Columns["id_rdv"].Visible = false;
                dgv_NonMeetings.Columns["Debut"].DisplayIndex = 0;
                dgv_NonMeetings.Columns["Debut"].HeaderText = "Dbut du rendez-vous";
                dgv_NonMeetings.Columns["Fin"].DisplayIndex = 1;

                dgv_NonMeetings.Columns["Nom"].DisplayIndex = 2;
                dgv_NonMeetings.Columns["Prenom"].DisplayIndex = 3;
                dgv_NonMeetings.Columns["DateNaissance"].DisplayIndex = 4;
                dgv_NonMeetings.Columns["DateNaissance"].HeaderText = "Date de naissance";

                dgv_NonMeetings.Columns["Fin"].HeaderText = "Fin du rendez-vous";
                dgv_NonMeetings.Columns["Honoraire"].DisplayIndex = 5;
                #endregion

            }
            #region Exception
            catch (Exception ex)
            {
                MessageBox.Show("Impossible de faire le listing des rendez-vous non pays!\r\n(" + ex.Message + ")",
                    "Attention", MessageBoxButtons.OK, MessageBoxIcon.Asterisk);
                Log.Instance.Write(ex.Message, "fr_HistoriqueNonCameMeeting.Ctor", LogType.Erreur);
            }
            #endregion
        }
        /// <summary>
        /// Put the meeting as "Came to meeting"
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Click_CameToMeeting(object sender, EventArgs e)
        {
            int IDMeeting = (int)dgv_NonMeetings.SelectedRows[0].Cells["id_rdv"].Value;
            PartialMeetingManager mm = PartialMeetingManager.Create(IDMeeting);
            fr_MeetingManager fr = new fr_MeetingManager();
            fr.Use = Use.Update;
            fr.MeetingManager = mm;
            fr.ShowDialog();
        }
        #endregion
    }
}